import 'package:mmoo_base/api/address.dart';
import 'package:mmoo_base/config/app_config.dart';
import 'package:mmoo_base/dao/base_dao.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/nowdao/new_model.dart';
import 'package:mmoo_base/nowdao/now_address.dart';
import 'package:mmoo_base/nowdao/now_house_entity.dart';
import 'package:mmoo_base/nowdao/now_house_list_entity.dart';
import 'package:mmoo_base/nowdao/now_user_entity.dart';
import 'package:sp_util/sp_util.dart';

class NowDao {
  static int nowUserId = 0;

  static Future<DataResult> reg(String id, [bool three = false]) async {
    var userId = SpUtil.getString(AppConfig.userNowId);
    var the = SpUtil.getBool(AppConfig.userIsThree);
    if (userId?.isEmpty == false && the == three) {
      nowUserId = int.parse(userId ?? '0');
      return DataResult(true, true);
    } else {
      SpUtil.putBool(AppConfig.userIsThree, three);
      Map other = {
        'email': id,
        'pwd': id,
      };
      var res =
          await BaseDao.fromBaseJson(other, NowAddress.reg(), token: false);
      if (res.result) {
        var entity = NowUserEntity.fromJson(res.data);
        SpUtil.putString(AppConfig.userNowId, entity.userId!);
        nowUserId = int.parse(entity.userId ?? '0');
        return DataResult(true, true);
      } else if (res.data.code == '-100') {
        var res2 =
            await BaseDao.fromBaseJson(other, NowAddress.login(), token: false);
        if (res2.result) {
          var entity = NowUserEntity.fromJson(res2.data);
          SpUtil.putString(AppConfig.userNowId, entity.id.toString());
          nowUserId = entity.id ?? 0;
          return DataResult(true, true);
        } else {
          return res2;
        }
      }
      return res;
    }
  }

  static Future<DataResult> createHouse(NowHouseEntity entity) async {
    Map other = {};
    other.addAll(entity.toJson());
    var res = await BaseDao.fromBaseJson(other, NowAddress.createHouse());
    if (res.result) {
      return DataResult(res, true);
    }
    return res;
  }

  static Future<DataResult> houseList() async {
    var res = await BaseDao.fromBaseJson({}, NowAddress.houseList());
    if (res.result) {
      var entity = NowHouseListEntity.fromJson(res.data);
      return DataResult(entity, true);
    }
    return res;
  }

  static Future<DataResult> updateHouse(NowHouseEntity entity) async {
    Map other = {};
    other.addAll(entity.toJson());
    var res = await BaseDao.fromBaseJson(other, NowAddress.updateHouse());
    if (res.result) {
      return DataResult(res, true);
    }
    return res;
  }

  static Future<DataResult> delHouse(int? id) async {
    Map other = {'id': id};
    var res = await BaseDao.fromBaseJson(other, NowAddress.delHouse());
    if (res.result) {
      return DataResult(res, true);
    }
    return res;
  }

  static Future<DataResult> getUserInfo(String userId) async {
    Map other = {'userId': userId};
    var res = await BaseDao.fromBaseJson(other, NowAddress.getUserInfo());
    if (res.result) {
      return DataResult(res, true);
    }
    return res;
  }

  static Future<DataResult> getEditInfo(
    String userid, {
    required Map map,
    String gender = '0',
  }) async {
    Map other = {'userId': userid, 'gender': gender};
    other.addAll(map);

    var res = await BaseDao.fromBaseJson(other, NowAddress.getEditInfo());
    if (res.result) {
      return DataResult(res, true);
    }
    return res;
  }

  static Future<DataResult> postUserModifyFunUser(
      {required NewModel model}) async {
    model.appPackage = Address.packageName;
    var res = await BaseDao.fromBaseEncryptV3(
      model.toJson(),
      NowAddress.modifyFunUser(),
    );
    if (res.result) {
      return DataResult(res.data, true);
    }
    return res;
  }

  static Future<DataResult> postUserModifyFunTre(
      {required NewModel model}) async {
    model.appPackage = Address.packageName;
    var res = await BaseDao.fromBaseEncryptV3(
      model.toJson(),
      NowAddress.modifyFunTree(),
    );
    if (res.result) {
      return DataResult(res.data, true);
    }
    return res;
  }

  static Future<DataResult> postUserSearchFunUser(
      {required NewModel model}) async {
    model.appPackage = Address.packageName;
    var res = await BaseDao.fromBaseEncryptV3(
      model.toJson(),
      NowAddress.searchFunUser(),
    );
    if (res.result) {
      return DataResult(res.data, true);
    }
    return res;
  }

  static Future<DataResult> postUserSearchFunTree(
      {required NewModel model}) async {
    model.appPackage = Address.packageName;
    var res = await BaseDao.fromBaseEncryptV3(
      model.toJson(),
      NowAddress.searchFunTree(),
    );
    if (res.result) {
      return DataResult(res.data, true);
    }
    return res;
  }

  static Future<DataResult> getDeleteFunTree({required int id}) async {
    var res = await BaseDao.fromBaseEncryptV3({}, NowAddress.deleteFunTree(),
        post: false, queryParameters: {'id': id});
    if (res.result) {
      return DataResult(res.data, true);
    }
    return res;
  }

  static Future<DataResult> getDeleteFunUser({required int id}) async {
    var res = await BaseDao.fromBaseEncryptV3({}, NowAddress.deleteFunUser(),
        post: false, queryParameters: {'id': id});
    if (res.result) {
      return DataResult(res.data, true);
    }
    return res;
  }
}
